3D examples
===========
These examples require raw data which are automatically
downloaded from the source repository by the script
:download:`example_helper.py <../examples/example_helper.py>`.
Please make sure that this script is present in the example
script folder.

.. fancy_include:: backprop_from_mie_3d_sphere.py

.. fancy_include:: backprop_from_fdtd_3d.py

.. fancy_include:: backprop_from_fdtd_3d_tilted.py

.. fancy_include:: backprop_from_fdtd_3d_tilted2.py

